A simple example of a detector that wraps around a MobileNet model trained on
COCO. It is used to detect people in frames.

Runtime options are provided to adjust the confidence threshold for detections
and to set a maximum frame size when processing.

Model: ssd_mobilenet_v1_coco

Dataset: Coco

From Tensorflow model zoo: https://github.com/tensorflow/models/blob/master/research/object_detection/g3doc/detection_model_zoo.md

## Model File License

Copyright 2017 The TensorFlow Authors. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

